//@line 4 "/builds/slave/c-cen-t-lnx-l10n-ntly/build/l10n/lt/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/c-cen-t-lnx-l10n-ntly/build/l10n/lt/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/c-cen-t-lnx-l10n-ntly/build/l10n/lt/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/slave/c-cen-t-lnx-l10n-ntly/build/l10n/lt/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "lt");

//@line 23 "/builds/slave/c-cen-t-lnx-l10n-ntly/build/l10n/lt/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Jubiliejus,Gimtadienis,Reikalai,Skambutis,Klientai,Konkursas,Pirkėjai,Laisvalaikis,Pakartotinas įvykis,Dovana,Atostogos,Idėja,Problema,Įvairūs,Asmeniška,Projektai,Šventė,Tiekėjai,Kelionė");
